==> rw_banks-0.0.2-py3-none-any.whl: rw_banks/__init__.py <==
banks = [
  {
    "name": "AB BANK RWANDA LTD",
    "swift_code": "ABBRRWRW",
    "bank_code": "ABBR",
    "postal_code": "671",
    "address": "15 KN 78 St, Kigali, Rwanda",
    "phone_number": "+250782298060",
    "toll_free": None,
    "email_address": "support@abbank.rw",
    "ussd_code": None
  },
  {
    "name": "BANK OF KIGALI LIMITED",
    "swift_code": "BKIGRWRW",
    "bank_code": "BKIG",
    "address": "KN 4 Ave, Kigali, Rwanda",
    "postal_code": "175",
    "phone_number": "+250788143000",
    "toll_free": "4455",
    "email_address": "bk@bk.rw",
    "ussd_code": "*334#"
  },
  {
    "name": "ACCESS BANK (RWANDA) PLC",
    "swift_code": "BKORRWRW",
    "bank_code": "BKOR",
    "address": "UTC, 3rd Floor, KN 4 Ave, Kigali, Rwanda",
    "postal_code": "2059",
    "phone_number": "+250788145300",
    "toll_free": None,
    "email_address": "rwandacontactcenter@accessbankplc.com",
    "ussd_code": "*903#"
  },
  {
    "name": "BANQUE NATIONALE DU RWANDA (BNR)",
    "swift_code": "BNRWRWRP",
    "bank_code": "BNRW",
    "address": "4 KN 6 Ave, Kigali, Rwanda",
    "postal_code": "531",
    "phone_number": "+250788199000",
    "toll_free": None,
    "email_address": "info@bnr.rw",
    "ussd_code": None
  },
  {
    "name": "DEVELOPMENT BANK OF RWANDA PLC",
    "swift_code": "BRDRRWRW",
    "bank_code": "BRDR",
    "address": "Development Bank of Rwanda, KN 3 Ave, Kigali, Rwanda",
    "postal_code": "1341",
    "phone_number": "+250252575080",
    "toll_free": None,
    "email_address": "brd@brd.rw",
    "ussd_code": None
  },
  {
    "name": "COGEBANQUE PLC",
    "swift_code": "CGBKRWRW",
    "bank_code": "CGBK",
    "address": "KN 63 St, Kigali, Rwanda",
    "postal_code": "5230",
    "phone_number": "+25078815500",
    "toll_free": "5050",
    "email_address": "cogebank@cogebank.com",
    "ussd_code": "*505#"
  },
  {
    "name": "ECOBANK RWANDA",
    "swift_code": "ECOCRWRW",
    "bank_code": "ECOC",
    "address": "KN 3 Ave, Kigali, Rwanda",
    "postal_code": None,
    "phone_number": "+250788161000",
    "toll_free": None,
    "email_address": "ecobankenquiries@ecobank.com",
    "ussd_code": None
  },
  {
    "name": "EQUITY BANK RWANDA LIMITED",
    "swift_code": "EQBLRWRW",
    "bank_code": "EQBL",
    "address": "Grand Pension Plaza, 1st Floor, KN 4 Ave, Kigali, Rwanda",
    "postal_code": "494",
    "phone_number": "+250788190000",
    "toll_free": None,
    "email_address": "info-rwanda@equitybank.co.rw",
    "ussd_code": "*247#"
  },
  {
    "name": "KCB BANK RWANDA LTD",
    "swift_code": "KCBLRWRW",
    "bank_code": "KCBL",
    "address": "18 KN 4 Ave, Kigali, Rwanda",
    "postal_code": "5620",
    "phone_number": "+250788140400",
    "toll_free": None,
    "email_address": "contactus@rw.kcbbankgroup.com",
    "ussd_code": "*522#"
  },
  {
    "name": "URWEGO OPPORTUNITY BANK LIMITED",
    "swift_code": "UOBRRWRW",
    "bank_code": "UOBR",
    "address": "UMUYENZI PLAZA AIRPORT ROAD",
    "postal_code": "748",
    "phone_number": "+250788173100",
    "toll_free": "5151",
    "email_address": "info@urwegobank.com",
    "ussd_code": "*501#"
  },
  {
    "name": "BANQUE DE L'HABITAT DU RWANDA",
    "swift_code": "LHRWRWR1",
    "bank_code": "LHRW",
    "address": "AVENUE DE LA JUSTICE",
    "postal_code": "1034",
    "phone_number": "+250571747",
    "toll_free": None,
    "email_address": None,
    "ussd_code": None
  },
  {
    "name": "GUARANTY TRUST BANK (RWANDA) LTD",
    "swift_code": "GTBIRWRK",
    "bank_code": "GTBI",
    "address": "KN 2 Ave,1370",
    "postal_code": "331",
    "phone_number": "+250788149600",
    "toll_free": None,
    "email_address": "info@gtbank.com",
    "ussd_code": None
  },
  {
    "name": "BANQUE POPULAIRE DU RWANDA LTD",
    "swift_code": "BPRWRWRW",
    "bank_code": "BPRW",
    "address": "KN 67 St, Kigali, Rwanda",
    "postal_code": "1348",
    "phone_number": "+250788187200",
    "toll_free": "1500",
    "email_address": "customerservice@bpr.rw",
    "ussd_code": "*150#"
  },
  {
    "name": "BANK OF AFRICA RWANDA LTD",
    "swift_code": "AFRWRWRW",
    "bank_code": "AFRW",
    "address": "CHIC Building,, Kigali, Rwanda",
    "postal_code": "265",
    "phone_number": "+250788136205",
    "toll_free": "5120",
    "email_address": "info@boarwanda.com",
    "ussd_code": None
  },
  {
    "name": "I&M BANK PLC",
    "swift_code": "IMRWRWRW",
    "bank_code": "IMRW",
    "address": "9 KN 3 Ave, Kigali, Rwanda",
    "postal_code": "354",
    "phone_number": "+250788162006",
    "toll_free": "3227",
    "email_address": "customerservices@imbank.co.rw",
    "ussd_code": None
  },
  {
    "name": "NCBA BANK RWANDA PLC",
    "swift_code": "NCBAFRWRW",
    "bank_code": "NCBAF",
    "address": "Muhima, Nyarugenge, Umujyi wa, Kigali, Rwanda",
    "postal_code": None,
    "phone_number": "+250788691568",
    "toll_free": None,
    "email_address": None,
    "ussd_code": None
  }
]
def getBanks():
  """ Method to return all licensed banks from Rwanda """
  return banks

def getBank(swift_code):
  
  """Method to retreive a licensed bank by swift code.

    Args:
        swift_code: pass in the swift code in the function to return a bank with that swift code
    """
  if swift_code:
    try:
        bank = [bank for bank in banks if bank["swift_code"] == swift_code]
        return bank[0]
    except IndexError:
        return None

==> rw_banks-0.0.3-py3-none-any.whl: rw_banks/__init__.py <==
banks = [
  {
    "name": "AB BANK RWANDA LTD",
    "swift_code": "ABBRRWRW",
    "bank_code": "ABBR",
    "postal_code": "671",
    "address": "15 KN 78 St, Kigali, Rwanda",
    "phone_number": "+250782298060",
    "toll_free": None,
    "email_address": "support@abbank.rw",
    "ussd_code": None
  },
  {
    "name": "BANK OF KIGALI LIMITED",
    "swift_code": "BKIGRWRW",
    "bank_code": "BKIG",
    "address": "KN 4 Ave, Kigali, Rwanda",
    "postal_code": "175",
    "phone_number": "+250788143000",
    "toll_free": "4455",
    "email_address": "bk@bk.rw",
    "ussd_code": "*334#"
  },
  {
    "name": "ACCESS BANK RWANDA PLC",
    "swift_code": "BKORRWRW",
    "bank_code": "BKOR",
    "address": "UTC, 3rd Floor, KN 4 Ave, Kigali, Rwanda",
    "postal_code": "2059",
    "phone_number": "+250788145300",
    "toll_free": None,
    "email_address": "rwandacontactcenter@accessbankplc.com",
    "ussd_code": "*903#"
  },
  {
    "name": "BANQUE NATIONALE DU RWANDA (BNR)",
    "swift_code": "BNRWRWRP",
    "bank_code": "BNRW",
    "address": "4 KN 6 Ave, Kigali, Rwanda",
    "postal_code": "531",
    "phone_number": "+250788199000",
    "toll_free": None,
    "email_address": "info@bnr.rw",
    "ussd_code": None
  },
  {
    "name": "DEVELOPMENT BANK OF RWANDA PLC",
    "swift_code": "BRDRRWRW",
    "bank_code": "BRDR",
    "address": "Development Bank of Rwanda, KN 3 Ave, Kigali, Rwanda",
    "postal_code": "1341",
    "phone_number": "+250252575080",
    "toll_free": None,
    "email_address": "brd@brd.rw",
    "ussd_code": None
  },
  {
    "name": "COGEBANQUE PLC",
    "swift_code": "CGBKRWRW",
    "bank_code": "CGBK",
    "address": "KN 63 St, Kigali, Rwanda",
    "postal_code": "5230",
    "phone_number": "+25078815500",
    "toll_free": "5050",
    "email_address": "cogebank@cogebank.com",
    "ussd_code": "*505#"
  },
  {
    "name": "ECOBANK RWANDA",
    "swift_code": "ECOCRWRW",
    "bank_code": "ECOC",
    "address": "KN 3 Ave, Kigali, Rwanda",
    "postal_code": None,
    "phone_number": "+250788161000",
    "toll_free": None,
    "email_address": "ecobankenquiries@ecobank.com",
    "ussd_code": None
  },
  {
    "name": "EQUITY BANK RWANDA LIMITED",
    "swift_code": "EQBLRWRW",
    "bank_code": "EQBL",
    "address": "Grand Pension Plaza, 1st Floor, KN 4 Ave, Kigali, Rwanda",
    "postal_code": "494",
    "phone_number": "+250788190000",
    "toll_free": None,
    "email_address": "info-rwanda@equitybank.co.rw",
    "ussd_code": "*555#"
  },
  {
    "name": "KCB BANK RWANDA LTD",
    "swift_code": "KCBLRWRW",
    "bank_code": "KCBL",
    "address": "18 KN 4 Ave, Kigali, Rwanda",
    "postal_code": "5620",
    "phone_number": "+250788140400",
    "toll_free": None,
    "email_address": "contactus@rw.kcbbankgroup.com",
    "ussd_code": "*522#"
  },
  {
    "name": "URWEGO OPPORTUNITY BANK LIMITED",
    "swift_code": "UOBRRWRW",
    "bank_code": "UOBR",
    "address": "UMUYENZI PLAZA AIRPORT ROAD",
    "postal_code": "748",
    "phone_number": "+250788173100",
    "toll_free": "5151",
    "email_address": "info@urwegobank.com",
    "ussd_code": "*501#"
  },
  {
    "name": "BANQUE DE L'HABITAT DU RWANDA",
    "swift_code": "LHRWRWR1",
    "bank_code": "LHRW",
    "address": "AVENUE DE LA JUSTICE",
    "postal_code": "1034",
    "phone_number": "+250571747",
    "toll_free": None,
    "email_address": None,
    "ussd_code": None
  },
  {
    "name": "GUARANTY TRUST BANK (RWANDA) LTD",
    "swift_code": "GTBIRWRK",
    "bank_code": "GTBI",
    "address": "KN 2 Ave,1370",
    "postal_code": "331",
    "phone_number": "+250788149600",
    "toll_free": None,
    "email_address": "info@gtbank.com",
    "ussd_code": None
  },
  {
    "name": "BANQUE POPULAIRE DU RWANDA LTD",
    "swift_code": "BPRWRWRW",
    "bank_code": "BPRW",
    "address": "KN 67 St, Kigali, Rwanda",
    "postal_code": "1348",
    "phone_number": "+250788187200",
    "toll_free": "1500",
    "email_address": "customerservice@bpr.rw",
    "ussd_code": "*150#"
  },
  {
    "name": "BANK OF AFRICA RWANDA LTD",
    "swift_code": "AFRWRWRW",
    "bank_code": "AFRW",
    "address": "CHIC Building,, Kigali, Rwanda",
    "postal_code": "265",
    "phone_number": "+250788136205",
    "toll_free": "5120",
    "email_address": "info@boarwanda.com",
    "ussd_code": None
  },
  {
    "name": "I&M BANK PLC",
    "swift_code": "IMRWRWRW",
    "bank_code": "IMRW",
    "address": "9 KN 3 Ave, Kigali, Rwanda",
    "postal_code": "354",
    "phone_number": "+250788162006",
    "toll_free": "3227",
    "email_address": "customerservices@imbank.co.rw",
    "ussd_code": None
  },
  {
    "name": "NCBA BANK RWANDA PLC",
    "swift_code": "NCBAFRWRW",
    "bank_code": "NCBAF",
    "address": "Muhima, Nyarugenge, Umujyi wa, Kigali, Rwanda",
    "postal_code": None,
    "phone_number": "+250788691568",
    "toll_free": None,
    "email_address": None,
    "ussd_code": None
  }
]
def getBanks():
  """ Method to return all licensed banks from Rwanda """
  return banks

def getBank(swift_code):
  
  """Method to retreive a licensed bank by swift code.

    Args:
        swift_code: pass in the swift code in the function to return a bank with that swift code
    """
  if swift_code:
    try:
        bank = [bank for bank in banks if bank["swift_code"] == swift_code]
        return bank[0]
    except IndexError:
        return None
